# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import winrt.system
from winrt import _winrt_windows_applicationmodel_holographic

__all__ = [
    "HolographicKeyboard",
]

HolographicKeyboard = _winrt_windows_applicationmodel_holographic.HolographicKeyboard



# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.1

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.foundation.numerics
import winrt.windows.perception.spatial

Self = typing.TypeVar('Self')

class HolographicKeyboard_Static(type):
    def get_default(cls) -> typing.Optional[HolographicKeyboard]: ...

class HolographicKeyboard(winrt.system.Object, metaclass=HolographicKeyboard_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> HolographicKeyboard: ...
    def reset_placement_override(self) -> None: ...
    @typing.overload
    def set_placement_override(self, coordinate_system: typing.Optional[winrt.windows.perception.spatial.SpatialCoordinateSystem], top_center_position: winrt.windows.foundation.numerics.Vector3, orientation: winrt.windows.foundation.numerics.Quaternion, /) -> None: ...
    @typing.overload
    def set_placement_override(self, coordinate_system: typing.Optional[winrt.windows.perception.spatial.SpatialCoordinateSystem], top_center_position: winrt.windows.foundation.numerics.Vector3, orientation: winrt.windows.foundation.numerics.Quaternion, max_size: winrt.windows.foundation.numerics.Vector2, /) -> None: ...

